Module session
git_
meta_
lib
0.1.10
Module session
Module Items
Structs
In crate git_
meta_
lib
git_meta_lib
Module
session
The library entry point: a session combining a git repo with a metadata store.
Structs

Session
A session combining a Git repository with its gmeta metadata store.