#[non_exhaustive]pub enum MetaEdit<'a> {
ListAppend {
key: &'a str,
entries: &'a [ListEntry],
},
SetAdd {
key: &'a str,
members: &'a [String],
},
}Expand description
A metadata edit that can be applied atomically with other edits.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl<'a> MetaEdit<'a>
impl<'a> MetaEdit<'a>
Sourcepub fn list_append(key: &'a str, entries: &'a [ListEntry]) -> Self
pub fn list_append(key: &'a str, entries: &'a [ListEntry]) -> Self
Append entries to a list value.
Entry timestamps preserve caller ordering. If an entry timestamp would collide with or sort before an existing list item, GitMeta shifts it forward to keep the appended entries at the end of the list.